<?php

namespace Litecms\Advert\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Advert\Actions\AdvertAction;
use Litecms\Advert\Http\Requests\AdvertActionRequest;
use Litecms\Advert\Http\Resources\AdvertResource;
use Litecms\Advert\Models\Advert;

/**
 * Admin web controller class.
 */
class AdvertActionController extends BaseController
{

    /**
     * Action controller function for advert.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AdvertActionRequest $request, Advert $advert, $action)
    {
        try {
            $request = $request->all();
            $advert = AdvertAction::run($action, $advert, $request);

            $data = new AdvertResource($advert);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('advert::advert.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('advert/advert/' . $advert->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advert/advert/' . $advert->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
