<?php

namespace Litecms\Advert\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Advert\Http\Requests\AdvertActionsRequest;
use Litecms\Advert\Actions\AdvertActions;

/**
 * Admin web controller class.
 */
class AdvertActionsController extends BaseController
{

    /**
     * Action controller function for advert.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AdvertActionsRequest $request, $action)
    {
        try {
            $advert = AdvertActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('advert::advert.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('advert/advert/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advert/advert/' . $action))
                ->redirect();
        }
    }
}
