<?php

namespace Litecms\Advert\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litecms\Advert\Actions\AdvertExim;
use Litecms\Advert\Http\Requests\AdvertEximRequest;

/**
 * Admin web controller class.
 */
class AdvertEximController extends BaseController
{
    /**
     * Action controller function for advert.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AdvertEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = AdvertExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('advert:advert.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('advert/advert/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('advert/advert/' . $exim))
                ->redirect();
        }
    }
}
