<?php

namespace Litecms\Advert\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Advert\Http\Resources\AdvertResource;
use Litecms\Advert\Http\Resources\AdvertsCollection;
use Litecms\Advert\Scopes\AdvertPublicScope;
use Litecms\Advert\Models\Advert;

class AdvertPublicController extends BaseController
{

    /**
     * Show advert's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Advert::pushScope(new RequestScope())
            ->pushScope(new AdvertPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $adverts = new AdvertsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('advert::advert.names'))
            ->view('advert::public.advert.index')
            ->data(compact('adverts', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show advert.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Advert::findBySlug($slug);
        $data = new AdvertResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('advert::advert.name'))
            ->view('advert::public.advert.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
