<?php

namespace Litecms\Advert\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Advert\Events\AdvertWorkflow as AdvertWorkflowEvent;
use Litecms\Advert\Notifications\AdvertWorkflow as AdvertWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AdvertWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AdvertWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $advert is submitted.
     *
     * @param AdvertWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AdvertWorkflowEvent $event)
    {
        $client = $event->advert->client;
        Notification::send($client, new AdvertWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $advert is published.
     *
     * @param AdvertWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AdvertWorkflowEvent $event)
    {
        $client = $event->advert->client;
        Notification::send($client, new AdvertWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $advert is approved.
     *
     * @param AdvertWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AdvertWorkflowEvent $event)
    {
        $client = $event->advert->client;
        Notification::send($client, new AdvertWorkflowNotification($event));
    }

    /**
     * Handles the $advert workflow event as a listener.
     *
     * @param AdvertWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AdvertWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
