<?php
namespace Litecms\Advert\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Advert\Events\AdvertAction as AdvertActionEvent;
use Litecms\Advert\Models\Advert;

class AdvertAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $advert;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AdvertActionEvent $advert
     */
    public function __construct(AdvertActionEvent $advert)
    {
        $this->action = $event->action;
        $this->advert = $advert;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Advert Approved - ' . config('app.name'))
            ->view('advert::advert.email.action', ['data' => $this->advert]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
