<?php

namespace Litecms\Advert\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Advert\Models\Advert;

class AdvertPolicy
{

    use AdvertAction;
    use AdvertExim;
    use AdvertReport;
    use AdvertWorkflow;

    /**
     * Determine if the given user can view the advert.
     *
     * @param UserPolicyInterface $authUser
     * @param Advert $advert
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Advert $advert)
    {
        if ($authUser->canDo('advert.advert.view') && $authUser->isAdmin()) {
            return true;
        }

        return $advert->user_id == user_id() && $advert->user_type == user_type();
    }

    /**
     * Determine if the given user can create a advert.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('advert.advert.create');
    }

    /**
     * Determine if the given user can update the given advert.
     *
     * @param UserPolicyInterface $authUser
     * @param Advert $advert
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Advert $advert)
    {
        if ($authUser->canDo('advert.advert.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $advert->user_id == user_id() && $advert->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given advert.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Advert $advert)
    {
        return $advert->user_id == user_id() && $advert->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given advert.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Advert $advert)
    {
        if ($authUser->canDo('advert.advert.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given advert.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Advert $advert)
    {
        if ($authUser->canDo('advert.advert.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
