<?php

namespace Litecms\Advert\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Advert\Adverts;

class AdvertServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'advert');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'advert');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerCommands();

        $this->app->register(\Litecms\Advert\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Advert\Providers\RouteServiceProvider::class);
        $this->app->register(\Litecms\Advert\Providers\ActionServiceProvider::class);
        $this->app->register(\Litecms\Advert\Providers\EventServiceProvider::class);
        $this->app->register(\Litecms\Advert\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.advert', function($app)
        {
            return $this->app->make(Advert::class);
        });
    }

    /**
     * Merges user's and advert's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.advert'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/advert.php', 'litecms.advert.advert'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/category.php', 'litecms.advert.category'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\Advert\Commands\Advert::class,
            ]);
        }
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.advert'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litecms/advert')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/advert')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/advert')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
